/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.orchestra.viewController;

/**
 * An interface for use with the InterfaceViewControllerExecutor.
 * <p>
 * When the InterfaceViewControllerExecutor has been selected as the technique for mapping
 * lifecycle events onto bean methods, then the target bean must implement this interface
 * in order to get callbacks.
 * <p>
 * Note that the expression "view controller bean" is used to generally refer to an object
 * that can handle lifecycle events for a view. Such beans may implement this interface, but
 * may not - they might be accessed via the ReflectiveViewControllerExecutor or other
 * implementations that do not require this interface. 
 */
public interface ViewController
{
    public void initView();

    public void preProcess();
    
    public void preRenderView();
}
